@@ -6,513 +6,529 @@
 
 #include "actionsmodel.h"
 
-#include <KConfigGroup>
-
 #include <QMessageBox>
 #include <QPushButton>
 
+#include <KConfigGroup>
+
 #include "global.h"
 
+using namespace Qt::StringLiterals;
+
 ActionsModel::ActionsModel(QObject *parent)
     : QAbstractListModel(parent)
     , m_config(KSharedConfig::openConfig(Global::instance()->appConfigFilePath(Global::ConfigFile::Shortcuts)))
 {
     Action action;
-    action.name = QStringLiteral("openActionsDialogAction");
+    action.name = u"openActionsDialogAction"_s;
     action.text = i18nc("@action", "Open Actions Dialog");
     action.defaultShortcut = Qt::CTRL | Qt::Key_QuoteLeft; // Key_QuoteLeft =  backtick
     action.shortcut = getShortcut(action.name, action.defaultShortcut);
     m_actions << action;
 
-    action.name = QStringLiteral("aboutHarunaAction");
+    action.name = u"aboutHarunaAction"_s;
     action.text = i18nc("@action", "About Haruna");
-    action.iconName = QStringLiteral("haruna");
+    action.iconName = u"haruna"_s;
     action.defaultShortcut = Qt::Key_F1;
     action.shortcut = getShortcut(action.name, action.defaultShortcut);
     m_actions << action;
 
-    action.name = QStringLiteral("audioCycleUpAction");
+    action.name = u"reportBugAction"_s;
+    action.text = i18nc("@action", "Report bug");
+    action.iconName = u"tools-report-bug"_s;
+    action.defaultShortcut = Qt::CTRL | Qt::SHIFT | Qt::Key_F1;
+    action.shortcut = getShortcut(action.name, action.defaultShortcut);
+    m_actions << action;
+
+    action.name = u"sponsorAction"_s;
+    action.text = i18nc("@action", "Sponsor Haruna");
+    action.iconName = u"help-donate-ars"_s;
+    action.defaultShortcut = Qt::Key_Dollar;
+    action.shortcut = getShortcut(action.name, action.defaultShortcut);
+    m_actions << action;
+
+    action.name = u"audioCycleUpAction"_s;
     action.text = i18nc("@action", "Audio Cycle Up");
     action.iconName = QString();
     action.defaultShortcut = Qt::SHIFT | Qt::Key_3;
     action.shortcut = getShortcut(action.name, action.defaultShortcut);
     m_actions << action;
 
-    action.name = QStringLiteral("audioCycleDownAction");
+    action.name = u"audioCycleDownAction"_s;
     action.text = i18nc("@action", "Audio Cycle Down");
     action.iconName = QString();
     action.defaultShortcut = Qt::SHIFT | Qt::Key_2;
     action.shortcut = getShortcut(action.name, action.defaultShortcut);
     m_actions << action;
 
-    action.name = QStringLiteral("configureAction");
-    action.text = i18nc("@action", "Configure");
-    action.iconName = QStringLiteral("configure");
+    action.name = u"configureAction"_s;
+    action.text = i18nc("@action", "Settings");
+    action.iconName = u"configure"_s;
     action.defaultShortcut = Qt::CTRL | Qt::SHIFT | Qt::Key_Comma;
     action.shortcut = getShortcut(action.name, action.defaultShortcut);
     m_actions << action;
 
-    action.name = QStringLiteral("configureShortcutsAction");
+    action.name = u"configureShortcutsAction"_s;
     action.text = i18nc("@action", "Configure Keyboard Shortcuts");
-    action.iconName = QStringLiteral("configure-shortcuts");
+    action.iconName = u"configure-shortcuts"_s;
     action.defaultShortcut = Qt::CTRL | Qt::ALT | Qt::Key_Comma;
     action.shortcut = getShortcut(action.name, action.defaultShortcut);
     m_actions << action;
 
-    action.name = QStringLiteral("exitFullscreenAction");
+    action.name = u"exitFullscreenAction"_s;
     action.text = i18nc("@action", "Exit Fullscreen");
     action.iconName = QString();
     action.defaultShortcut = Qt::Key_Escape;
     action.shortcut = getShortcut(action.name, action.defaultShortcut);
     m_actions << action;
 
-    action.name = QStringLiteral("frameStepForwardAction");
+    action.name = u"frameStepForwardAction"_s;
     action.text = i18nc("@action", "Frame Step Forward");
     action.iconName = QString();
     action.defaultShortcut = Qt::Key_Period;
     action.shortcut = getShortcut(action.name, action.defaultShortcut);
-    action.description = QStringLiteral("Move one frame forward, then pause");
+    action.description = u"Move one frame forward, then pause"_s;
     m_actions << action;
 
-    action.name = QStringLiteral("frameStepBackwardAction");
+    action.name = u"frameStepBackwardAction"_s;
     action.text = i18nc("@action", "Frame Step Backward");
     action.iconName = QString();
     action.defaultShortcut = Qt::Key_Comma;
     action.shortcut = getShortcut(action.name, action.defaultShortcut);
-    action.description = QStringLiteral("Move one frame backward, then pause");
+    action.description = u"Move one frame backward, then pause"_s;
     m_actions << action;
 
-    action.name = QStringLiteral("loadLastPlayedFileAction");
+    action.name = u"loadLastPlayedFileAction"_s;
     action.text = i18nc("@action", "Load Last Played File");
-    action.iconName = QStringLiteral("document-open-recent");
+    action.iconName = u"document-open-recent"_s;
     action.defaultShortcut = Qt::CTRL | Qt::SHIFT | Qt::Key_L;
     action.shortcut = getShortcut(action.name, action.defaultShortcut);
     m_actions << action;
 
-    action.name = QStringLiteral("muteAction");
+    action.name = u"muteAction"_s;
     action.text = i18nc("@action", "Mute");
-    action.iconName = QStringLiteral("player-volume-muted");
+    action.iconName = u"player-volume-muted"_s;
     action.defaultShortcut = Qt::Key_M;
     action.shortcut = getShortcut(action.name, action.defaultShortcut);
     m_actions << action;
 
-    action.name = QStringLiteral("openContextMenuAction");
+    action.name = u"openContextMenuAction"_s;
     action.text = i18nc("@action", "Open Context Menu");
-    action.iconName = QStringLiteral("application-menu");
+    action.iconName = u"application-menu"_s;
     action.defaultShortcut = Qt::Key_Menu;
     action.shortcut = getShortcut(action.name, action.defaultShortcut);
     action.description = i18nc("@action", "Opens and closes the context menu at the position of the mouse pointer");
     m_actions << action;
 
-    action.name = QStringLiteral("openFileAction");
+    action.name = u"openFileAction"_s;
     action.text = i18nc("@action", "Open File");
-    action.iconName = QStringLiteral("folder-videos");
+    action.iconName = u"folder-videos"_s;
     action.defaultShortcut = Qt::CTRL | Qt::Key_O;
     action.shortcut = getShortcut(action.name, action.defaultShortcut);
     m_actions << action;
 
-    action.name = QStringLiteral("openSubtitlesFileAction");
+    action.name = u"openSubtitlesFileAction"_s;
     action.text = i18nc("@action", "Add External Subtitle…");
-    action.iconName = QStringLiteral("add-subtitle");
+    action.iconName = u"add-subtitle"_s;
     action.defaultShortcut = Qt::ALT | Qt::Key_S;
     action.shortcut = getShortcut(action.name, action.defaultShortcut);
     m_actions << action;
 
-    action.name = QStringLiteral("openUrlAction");
+    action.name = u"openUrlAction"_s;
     action.text = i18nc("@action", "Open Url");
-    action.iconName = QStringLiteral("internet-services");
+    action.iconName = u"internet-services"_s;
     action.defaultShortcut = Qt::CTRL | Qt::SHIFT | Qt::Key_O;
     action.shortcut = getShortcut(action.name, action.defaultShortcut);
     m_actions << action;
 
-    action.name = QStringLiteral("playbackSpeedIncreaseAction");
+    action.name = u"playbackSpeedIncreaseAction"_s;
     action.text = i18nc("@action", "Playback Speed Increase");
     action.iconName = QString();
     action.defaultShortcut = Qt::Key_BracketRight;
     action.shortcut = getShortcut(action.name, action.defaultShortcut);
     m_actions << action;
 
-    action.name = QStringLiteral("playbackSpeedDecreaseAction");
+    action.name = u"playbackSpeedDecreaseAction"_s;
     action.text = i18nc("@action", "Playback Speed Decrease");
     action.iconName = QString();
     action.defaultShortcut = Qt::Key_BracketLeft;
     action.shortcut = getShortcut(action.name, action.defaultShortcut);
     m_actions << action;
 
-    action.name = QStringLiteral("playbackSpeedResetAction");
+    action.name = u"playbackSpeedResetAction"_s;
     action.text = i18nc("@action", "Playback Speed Reset");
     action.iconName = QString();
     action.defaultShortcut = Qt::Key_Backspace;
     action.shortcut = getShortcut(action.name, action.defaultShortcut);
     m_actions << action;
 
-    action.name = QStringLiteral("playPauseAction");
+    action.name = u"playPauseAction"_s;
     action.text = i18nc("@action", "Play/Pause");
-    action.iconName = QStringLiteral("media-playback-pause");
+    action.iconName = u"media-playback-pause"_s;
     action.defaultShortcut = Qt::Key_Space;
     action.shortcut = getShortcut(action.name, action.defaultShortcut);
     m_actions << action;
 
-    action.name = QStringLiteral("playNextAction");
+    action.name = u"playNextAction"_s;
     action.text = i18nc("@action", "Play Next");
-    action.iconName = QStringLiteral("media-skip-forward");
+    action.iconName = u"media-skip-forward"_s;
     action.defaultShortcut = Qt::SHIFT | Qt::Key_Period;
     action.shortcut = getShortcut(action.name, action.defaultShortcut);
     m_actions << action;
 
-    action.name = QStringLiteral("playPreviousAction");
+    action.name = u"playPreviousAction"_s;
     action.text = i18nc("@action", "Play Previous");
-    action.iconName = QStringLiteral("media-skip-backward");
+    action.iconName = u"media-skip-backward"_s;
     action.defaultShortcut = Qt::SHIFT | Qt::Key_Comma;
     action.shortcut = getShortcut(action.name, action.defaultShortcut);
     m_actions << action;
 
-    action.name = QStringLiteral("quitApplicationAction");
+    action.name = u"quitApplicationAction"_s;
     action.text = i18nc("@action", "Quit");
-    action.iconName = QStringLiteral("application-exit");
+    action.iconName = u"application-exit"_s;
     action.defaultShortcut = Qt::CTRL | Qt::Key_Q;
     action.shortcut = getShortcut(action.name, action.defaultShortcut);
     m_actions << action;
 
-    action.name = QStringLiteral("restartPlaybackAction");
+    action.name = u"restartPlaybackAction"_s;
     action.text = i18nc("@action", "Restart Playback");
-    action.iconName = QStringLiteral("edit-reset");
+    action.iconName = u"edit-reset"_s;
     action.defaultShortcut = Qt::Key_F5;
     action.shortcut = getShortcut(action.name, action.defaultShortcut);
     m_actions << action;
 
-    action.name = QStringLiteral("seekForwardSmallAction");
+    action.name = u"seekForwardSmallAction"_s;
     action.text = i18nc("@action", "Seek Small Step Forward");
-    action.iconName = QStringLiteral("media-seek-forward");
+    action.iconName = u"media-seek-forward"_s;
     action.defaultShortcut = Qt::Key_Right;
     action.shortcut = getShortcut(action.name, action.defaultShortcut);
     m_actions << action;
 
-    action.name = QStringLiteral("seekBackwardSmallAction");
+    action.name = u"seekBackwardSmallAction"_s;
     action.text = i18nc("@action", "Seek Small Step Backward");
-    action.iconName = QStringLiteral("media-seek-backward");
+    action.iconName = u"media-seek-backward"_s;
     action.defaultShortcut = Qt::Key_Left;
     action.shortcut = getShortcut(action.name, action.defaultShortcut);
     m_actions << action;
 
-    action.name = QStringLiteral("seekForwardMediumAction");
+    action.name = u"seekForwardMediumAction"_s;
     action.text = i18nc("@action", "Seek Medium Step Forward");
-    action.iconName = QStringLiteral("media-seek-forward");
+    action.iconName = u"media-seek-forward"_s;
     action.defaultShortcut = Qt::SHIFT | Qt::Key_Right;
     action.shortcut = getShortcut(action.name, action.defaultShortcut);
     m_actions << action;
 
-    action.name = QStringLiteral("seekBackwardMediumAction");
+    action.name = u"seekBackwardMediumAction"_s;
     action.text = i18nc("@action", "Seek Medium Step Backward");
-    action.iconName = QStringLiteral("media-seek-backward");
+    action.iconName = u"media-seek-backward"_s;
     action.defaultShortcut = Qt::SHIFT | Qt::Key_Left;
     action.shortcut = getShortcut(action.name, action.defaultShortcut);
     m_actions << action;
 
-    action.name = QStringLiteral("seekForwardBigAction");
+    action.name = u"seekForwardBigAction"_s;
     action.text = i18nc("@action", "Seek Big Step Forward");
-    action.iconName = QStringLiteral("media-seek-forward");
+    action.iconName = u"media-seek-forward"_s;
     action.defaultShortcut = Qt::Key_Up;
     action.shortcut = getShortcut(action.name, action.defaultShortcut);
     m_actions << action;
 
-    action.name = QStringLiteral("seekBackwardBigAction");
+    action.name = u"seekBackwardBigAction"_s;
     action.text = i18nc("@action", "Seek Big Step Backward");
-    action.iconName = QStringLiteral("media-seek-backward");
+    action.iconName = u"media-seek-backward"_s;
     action.defaultShortcut = Qt::Key_Down;
     action.shortcut = getShortcut(action.name, action.defaultShortcut);
     m_actions << action;
 
-    action.name = QStringLiteral("seekNextChapterAction");
+    action.name = u"seekNextChapterAction"_s;
     action.text = i18nc("@action", "Seek Next Chapter");
-    action.iconName = QStringLiteral("media-seek-forward");
+    action.iconName = u"media-seek-forward"_s;
     action.defaultShortcut = Qt::Key_PageUp;
     action.shortcut = getShortcut(action.name, action.defaultShortcut);
     m_actions << action;
 
-    action.name = QStringLiteral("seekPreviousChapterAction");
+    action.name = u"seekPreviousChapterAction"_s;
     action.text = i18nc("@action", "Seek Previous Chapter");
-    action.iconName = QStringLiteral("media-seek-backward");
+    action.iconName = u"media-seek-backward"_s;
     action.defaultShortcut = Qt::Key_PageDown;
     action.shortcut = getShortcut(action.name, action.defaultShortcut);
     m_actions << action;
 
-    action.name = QStringLiteral("seekNextSubtitleAction");
+    action.name = u"seekNextSubtitleAction"_s;
     action.text = i18nc("@action", "Seek To Next Subtitle");
-    action.iconName = QStringLiteral("media-seek-forward");
+    action.iconName = u"media-seek-forward"_s;
     action.defaultShortcut = Qt::CTRL | Qt::Key_Right;
     action.shortcut = getShortcut(action.name, action.defaultShortcut);
     m_actions << action;
 
-    action.name = QStringLiteral("seekPreviousSubtitleAction");
+    action.name = u"seekPreviousSubtitleAction"_s;
     action.text = i18nc("@action", "Seek To Previous Subtitle");
-    action.iconName = QStringLiteral("media-seek-backward");
+    action.iconName = u"media-seek-backward"_s;
     action.defaultShortcut = Qt::CTRL | Qt::Key_Left;
     action.shortcut = getShortcut(action.name, action.defaultShortcut);
     m_actions << action;
 
-    action.name = QStringLiteral("seekToWatchLaterPositionAction");
+    action.name = u"seekToWatchLaterPositionAction"_s;
     action.text = i18nc("@action", "Seek To Watch Later Position");
-    action.iconName = QStringLiteral("pin");
+    action.iconName = u"pin"_s;
     action.defaultShortcut = Qt::CTRL | Qt::SHIFT | Qt::Key_P;
     action.shortcut = getShortcut(action.name, action.defaultShortcut);
     m_actions << action;
 
-    action.name = QStringLiteral("setLoopAction");
+    action.name = u"setLoopAction"_s;
     action.text = i18nc("@action", "Set Loop");
     action.iconName = QString();
     action.defaultShortcut = Qt::Key_L;
     action.shortcut = getShortcut(action.name, action.defaultShortcut);
     m_actions << action;
 
-    action.name = QStringLiteral("screenshotAction");
+    action.name = u"screenshotAction"_s;
     action.text = i18nc("@action", "Screenshot");
-    action.iconName = QStringLiteral("image-x-generic");
+    action.iconName = u"image-x-generic"_s;
     action.defaultShortcut = Qt::Key_S;
     action.shortcut = getShortcut(action.name, action.defaultShortcut);
     m_actions << action;
 
-    action.name = QStringLiteral("subtitleToggleAction");
+    action.name = u"subtitleToggleAction"_s;
     action.text = i18nc("@action", "Subtitle Toggle");
     action.iconName = QString();
     action.defaultShortcut = Qt::CTRL | Qt::Key_S;
     action.shortcut = getShortcut(action.name, action.defaultShortcut);
     m_actions << action;
 
-    action.name = QStringLiteral("subtitleIncreaseFontSizeAction");
+    action.name = u"subtitleIncreaseFontSizeAction"_s;
     action.text = i18nc("@action", "Subtitle Increase Font Size");
     action.iconName = QString();
     action.defaultShortcut = Qt::CTRL | Qt::Key_Z;
     action.shortcut = getShortcut(action.name, action.defaultShortcut);
     m_actions << action;
 
-    action.name = QStringLiteral("subtitleDecreaseFontSizeAction");
+    action.name = u"subtitleDecreaseFontSizeAction"_s;
     action.text = i18nc("@action", "Subtitle Decrease Font Size");
     action.iconName = QString();
     action.defaultShortcut = Qt::CTRL | Qt::Key_X;
     action.shortcut = getShortcut(action.name, action.defaultShortcut);
     m_actions << action;
 
-    action.name = QStringLiteral("subtitleMoveUpAction");
+    action.name = u"subtitleMoveUpAction"_s;
     action.text = i18nc("@action", "Subtitle Move Up");
     action.iconName = QString();
     action.defaultShortcut = Qt::Key_R;
     action.shortcut = getShortcut(action.name, action.defaultShortcut);
     m_actions << action;
 
-    action.name = QStringLiteral("subtitleMoveDownAction");
+    action.name = u"subtitleMoveDownAction"_s;
     action.text = i18nc("@action", "Subtitle Move Down");
     action.iconName = QString();
     action.defaultShortcut = Qt::SHIFT | Qt::Key_R;
     action.shortcut = getShortcut(action.name, action.defaultShortcut);
     m_actions << action;
 
-    action.name = QStringLiteral("subtitleQuickenAction");
+    action.name = u"subtitleQuickenAction"_s;
     action.text = i18nc("@action", "Subtitle Quicken");
     action.iconName = QString();
     action.defaultShortcut = Qt::Key_Z;
     action.shortcut = getShortcut(action.name, action.defaultShortcut);
     m_actions << action;
 
-    action.name = QStringLiteral("subtitleDelayAction");
+    action.name = u"subtitleDelayAction"_s;
     action.text = i18nc("@action", "Subtitle Delay");
     action.iconName = QString();
     action.defaultShortcut = Qt::SHIFT | Qt::Key_Z;
     action.shortcut = getShortcut(action.name, action.defaultShortcut);
     m_actions << action;
 
-    action.name = QStringLiteral("subtitleCycleUpAction");
+    action.name = u"subtitleCycleUpAction"_s;
     action.text = i18nc("@action", "Subtitle Cycle Up");
     action.iconName = QString();
     action.defaultShortcut = Qt::Key_J;
     action.shortcut = getShortcut(action.name, action.defaultShortcut);
     m_actions << action;
 
-    action.name = QStringLiteral("subtitleCycleDownAction");
+    action.name = u"subtitleCycleDownAction"_s;
     action.text = i18nc("@action", "Subtitle Cycle Down");
     action.iconName = QString();
     action.defaultShortcut = Qt::SHIFT | Qt::Key_J;
     action.shortcut = getShortcut(action.name, action.defaultShortcut);
     m_actions << action;
 
-    action.name = QStringLiteral("toggleDeinterlacingAction");
+    action.name = u"toggleDeinterlacingAction"_s;
     action.text = i18nc("@action", "Toggle Deinterlacing");
     action.iconName = QString();
     action.defaultShortcut = Qt::Key_D;
     action.shortcut = getShortcut(action.name, action.defaultShortcut);
     m_actions << action;
 
-    action.name = QStringLiteral("toggleFullscreenAction");
+    action.name = u"toggleFullscreenAction"_s;
     action.text = i18nc("@action", "Toggle Fullscreen");
-    action.iconName = QStringLiteral("view-fullscreen");
+    action.iconName = u"view-fullscreen"_s;
     action.defaultShortcut = Qt::Key_F;
     action.shortcut = getShortcut(action.name, action.defaultShortcut);
     m_actions << action;
 
-    action.name = QStringLiteral("toggleMenuBarAction");
+    action.name = u"toggleMenuBarAction"_s;
     action.text = i18nc("@action", "Toggle Menu Bar");
     action.iconName = QString();
     action.defaultShortcut = Qt::CTRL | Qt::Key_M;
     action.shortcut = getShortcut(action.name, action.defaultShortcut);
     m_actions << action;
 
-    action.name = QStringLiteral("toggleHeaderAction");
+    action.name = u"toggleHeaderAction"_s;
     action.text = i18nc("@action", "Toggle Header");
     action.iconName = QString();
     action.defaultShortcut = Qt::CTRL | Qt::Key_H;
     action.shortcut = getShortcut(action.name, action.defaultShortcut);
     m_actions << action;
 
-    action.name = QStringLiteral("togglePlaylistAction");
+    action.name = u"togglePlaylistAction"_s;
     action.text = i18nc("@action", "Playlist");
-    action.iconName = QStringLiteral("view-media-playlist");
+    action.iconName = u"view-media-playlist"_s;
     action.defaultShortcut = Qt::Key_P;
     action.shortcut = getShortcut(action.name, action.defaultShortcut);
     m_actions << action;
 
-    action.name = QStringLiteral("videoPanXLeftAction");
+    action.name = u"videoPanXLeftAction"_s;
     action.text = i18nc("@action", "Video Move Left");
     action.iconName = QString();
     action.defaultShortcut = Qt::CTRL | Qt::ALT | Qt::Key_Left;
     action.shortcut = getShortcut(action.name, action.defaultShortcut);
     m_actions << action;
 
-    action.name = QStringLiteral("videoPanXRightAction");
+    action.name = u"videoPanXRightAction"_s;
     action.text = i18nc("@action", "Video Move Right");
     action.iconName = QString();
     action.defaultShortcut = Qt::CTRL | Qt::ALT | Qt::Key_Right;
     action.shortcut = getShortcut(action.name, action.defaultShortcut);
     m_actions << action;
 
-    action.name = QStringLiteral("videoPanYUpAction");
+    action.name = u"videoPanYUpAction"_s;
     action.text = i18nc("@action", "Video Move Up");
     action.iconName = QString();
     action.defaultShortcut = Qt::CTRL | Qt::ALT | Qt::Key_Up;
     action.shortcut = getShortcut(action.name, action.defaultShortcut);
     m_actions << action;
 
-    action.name = QStringLiteral("videoPanYDownAction");
+    action.name = u"videoPanYDownAction"_s;
     action.text = i18nc("@action", "Video Move Down");
     action.iconName = QString();
     action.defaultShortcut = Qt::CTRL | Qt::ALT | Qt::Key_Down;
     action.shortcut = getShortcut(action.name, action.defaultShortcut);
     m_actions << action;
 
-    action.name = QStringLiteral("volumeUpAction");
+    action.name = u"volumeUpAction"_s;
     action.text = i18nc("@action", "Volume Up");
-    action.iconName = QStringLiteral("audio-volume-high");
+    action.iconName = u"audio-volume-high"_s;
     action.defaultShortcut = Qt::Key_9;
     action.shortcut = getShortcut(action.name, action.defaultShortcut);
     m_actions << action;
 
-    action.name = QStringLiteral("volumeDownAction");
+    action.name = u"volumeDownAction"_s;
     action.text = i18nc("@action", "Volume Down");
-    action.iconName = QStringLiteral("audio-volume-low");
+    action.iconName = u"audio-volume-low"_s;
     action.defaultShortcut = Qt::Key_0;
     action.shortcut = getShortcut(action.name, action.defaultShortcut);
     m_actions << action;
 
-    action.name = QStringLiteral("zoomInAction");
+    action.name = u"zoomInAction"_s;
     action.text = i18nc("@action", "Zoom In");
-    action.iconName = QStringLiteral("zoom-in");
+    action.iconName = u"zoom-in"_s;
     action.defaultShortcut = Qt::CTRL | Qt::Key_Plus;
     action.shortcut = getShortcut(action.name, action.defaultShortcut);
     m_actions << action;
 
-    action.name = QStringLiteral("zoomOutAction");
+    action.name = u"zoomOutAction"_s;
     action.text = i18nc("@action", "Zoom Out");
-    action.iconName = QStringLiteral("zoom-out");
+    action.iconName = u"zoom-out"_s;
     action.defaultShortcut = Qt::CTRL | Qt::Key_Minus;
     action.shortcut = getShortcut(action.name, action.defaultShortcut);
     m_actions << action;
 
-    action.name = QStringLiteral("zoomResetAction");
+    action.name = u"zoomResetAction"_s;
     action.text = i18nc("@action", "Zoom Reset");
-    action.iconName = QStringLiteral("zoom-original");
+    action.iconName = u"zoom-original"_s;
     action.defaultShortcut = Qt::CTRL | Qt::Key_0;
     action.shortcut = getShortcut(action.name, action.defaultShortcut);
     m_actions << action;
 
-    action.name = QStringLiteral("contrastUpAction");
+    action.name = u"contrastUpAction"_s;
     action.text = i18nc("@action", "Contrast Up");
-    action.iconName = QStringLiteral("contrast");
+    action.iconName = u"contrast"_s;
     action.defaultShortcut = Qt::Key_1;
     action.shortcut = getShortcut(action.name, action.defaultShortcut);
     m_actions << action;
 
-    action.name = QStringLiteral("contrastDownAction");
+    action.name = u"contrastDownAction"_s;
     action.text = i18nc("@action", "Contrast Down");
-    action.iconName = QStringLiteral("contrast");
+    action.iconName = u"contrast"_s;
     action.defaultShortcut = Qt::Key_2;
     action.shortcut = getShortcut(action.name, action.defaultShortcut);
     m_actions << action;
 
-    action.name = QStringLiteral("contrastResetAction");
+    action.name = u"contrastResetAction"_s;
     action.text = i18nc("@action", "Contrast Reset");
-    action.iconName = QStringLiteral("contrast");
+    action.iconName = u"contrast"_s;
     action.defaultShortcut = Qt::CTRL | Qt::Key_1;
     action.shortcut = getShortcut(action.name, action.defaultShortcut);
     m_actions << action;
 
-    action.name = QStringLiteral("brightnessUpAction");
+    action.name = u"brightnessUpAction"_s;
     action.text = i18nc("@action", "Brightness Up");
-    action.iconName = QStringLiteral("contrast");
+    action.iconName = u"contrast"_s;
     action.defaultShortcut = Qt::Key_3;
     action.shortcut = getShortcut(action.name, action.defaultShortcut);
     m_actions << action;
 
-    action.name = QStringLiteral("brightnessDownAction");
+    action.name = u"brightnessDownAction"_s;
     action.text = i18nc("@action", "Brightness Down");
-    action.iconName = QStringLiteral("contrast");
+    action.iconName = u"contrast"_s;
     action.defaultShortcut = Qt::Key_4;
     action.shortcut = getShortcut(action.name, action.defaultShortcut);
     m_actions << action;
 
-    action.name = QStringLiteral("brightnessResetAction");
+    action.name = u"brightnessResetAction"_s;
     action.text = i18nc("@action", "Brightness Reset");
-    action.iconName = QStringLiteral("contrast");
+    action.iconName = u"contrast"_s;
     action.defaultShortcut = Qt::CTRL | Qt::Key_3;
     action.shortcut = getShortcut(action.name, action.defaultShortcut);
     m_actions << action;
 
-    action.name = QStringLiteral("gammaUpAction");
+    action.name = u"gammaUpAction"_s;
     action.text = i18nc("@action", "Gamma Up");
-    action.iconName = QStringLiteral("contrast");
+    action.iconName = u"contrast"_s;
     action.defaultShortcut = Qt::Key_5;
     action.shortcut = getShortcut(action.name, action.defaultShortcut);
     m_actions << action;
 
-    action.name = QStringLiteral("gammaDownAction");
+    action.name = u"gammaDownAction"_s;
     action.text = i18nc("@action", "Gamma Down");
-    action.iconName = QStringLiteral("contrast");
+    action.iconName = u"contrast"_s;
     action.defaultShortcut = Qt::Key_6;
     action.shortcut = getShortcut(action.name, action.defaultShortcut);
     m_actions << action;
 
-    action.name = QStringLiteral("gammaResetAction");
+    action.name = u"gammaResetAction"_s;
     action.text = i18nc("@action", "Gamma Reset");
-    action.iconName = QStringLiteral("contrast");
+    action.iconName = u"contrast"_s;
     action.defaultShortcut = Qt::CTRL | Qt::Key_5;
     action.shortcut = getShortcut(action.name, action.defaultShortcut);
     m_actions << action;
 
-    action.name = QStringLiteral("saturationUpAction");
+    action.name = u"saturationUpAction"_s;
     action.text = i18nc("@action", "Saturation Up");
-    action.iconName = QStringLiteral("contrast");
+    action.iconName = u"contrast"_s;
     action.defaultShortcut = Qt::Key_7;
     action.shortcut = getShortcut(action.name, action.defaultShortcut);
     m_actions << action;
 
-    action.name = QStringLiteral("saturationDownAction");
+    action.name = u"saturationDownAction"_s;
     action.text = i18nc("@action", "Saturation Down");
-    action.iconName = QStringLiteral("contrast");
+    action.iconName = u"contrast"_s;
     action.defaultShortcut = Qt::Key_8;
     action.shortcut = getShortcut(action.name, action.defaultShortcut);
     m_actions << action;
 
-    action.name = QStringLiteral("saturationResetAction");
+    action.name = u"saturationResetAction"_s;
     action.text = i18nc("@action", "Saturation Reset");
-    action.iconName = QStringLiteral("contrast");
+    action.iconName = u"contrast"_s;
     action.defaultShortcut = Qt::CTRL | Qt::Key_7;
     action.shortcut = getShortcut(action.name, action.defaultShortcut);
     m_actions << action;
@@ -559,14 +575,18 @@ QVariant ActionsModel::data(const QModelIndex &index, int role) const
 
 QHash<int, QByteArray> ActionsModel::roleNames() const
 {
-    QHash<int, QByteArray> roles;
-    roles[NameRole] = "name";
-    roles[TextRole] = "text";
-    roles[IconRole] = "icon";
-    roles[ShortcutRole] = "shortcut";
-    roles[DefaultShortcutRole] = "defaultShortcut";
-    roles[DescriptionRole] = "description";
-    roles[TypeRole] = "type";
+    // clang-format off
+    QHash<int, QByteArray> roles{
+        {NameRole,            QByteArrayLiteral("actionName")},
+        {TextRole,            QByteArrayLiteral("actionText")},
+        {IconRole,            QByteArrayLiteral("actionIcon")},
+        {ShortcutRole,        QByteArrayLiteral("actionShortcut")},
+        {DefaultShortcutRole, QByteArrayLiteral("actionDefaultShortcut")},
+        {DescriptionRole,     QByteArrayLiteral("actionDescription")},
+        {TypeRole,            QByteArrayLiteral("actionType")},
+    };
+    // clang-format on
+
     return roles;
 }
 
@@ -589,30 +609,29 @@ void ActionsModel::editCustomAction(const QString &name, const QString &text, co
     }
 }
 
-bool ActionsModel::saveShortcut(const QString &name, const QVariant &shortcut)
+bool ActionsModel::saveShortcut(const QString &name, QKeySequence keySequence)
 {
     for (int i{0}; i < m_actions.count(); ++i) {
         if (m_actions[i].name == name) {
-            return saveShortcut(i, shortcut);
+            return saveShortcut(i, keySequence);
         }
     }
     return false;
 }
 
-bool ActionsModel::saveShortcut(int row, const QVariant &shortcut)
+bool ActionsModel::saveShortcut(int row, QKeySequence keySequence)
 {
-    auto group = m_config->group(QStringLiteral("Shortcuts"));
-    auto shortcutString = shortcut.value<QKeySequence>().toString(QKeySequence::PortableText);
+    auto group = m_config->group(u"Shortcuts"_s);
     // action whose shortcut is changed
     auto action = &m_actions[row];
 
     // if shortcut is being cleared, no need to search for a conflict
-    if (!shortcut.toString().isEmpty()) {
+    if (!keySequence.isEmpty()) {
         // if shortcut is used, this is the action holding the shortcut
         Action *result = nullptr;
         int i{0};
         for (; i < m_actions.count(); ++i) {
-            if (m_actions[i].shortcut == shortcutString) {
+            if (m_actions[i].shortcut == keySequence) {
                 result = &m_actions[i];
                 break;
             }
@@ -627,8 +646,8 @@ bool ActionsModel::saveShortcut(int row, const QVariant &shortcut)
             // ask user what whether to reassign or to cancel
             if (keyConflictMessageBox(result->text)) {
                 // user chose reassign, remove shortcut from action holding it
-                result->shortcut = QString();
-                group.writeEntry(result->name, result->shortcut);
+                result->shortcut = QKeySequence{};
+                group.writeEntry(result->name, QString{});
                 Q_EMIT shortcutChanged(result->name, result->shortcut);
                 Q_EMIT dataChanged(index(i, 0), index(i, 0));
             } else {
@@ -638,19 +657,20 @@ bool ActionsModel::saveShortcut(int row, const QVariant &shortcut)
         }
     }
     // set shortcut on the action being changed
-    action->shortcut = shortcutString;
-    group.writeEntry(action->name, action->shortcut);
+    action->shortcut = keySequence;
+    group.writeEntry(action->name, action->shortcut.toString(QKeySequence::PortableText));
     Q_EMIT shortcutChanged(action->name, action->shortcut);
     Q_EMIT dataChanged(index(row, 0), index(row, 0));
 
     return group.sync();
 }
 
-QString ActionsModel::getShortcut(const QString &key, const QKeySequence &defaultValue) const
+QKeySequence ActionsModel::getShortcut(const QString &key, const QKeySequence &defaultValue) const
 {
     auto v = defaultValue.toString(QKeySequence::PortableText);
-    auto group = m_config->group(QStringLiteral("Shortcuts"));
-    return group.readEntry(key, v);
+    auto group = m_config->group(u"Shortcuts"_s);
+    QKeySequence keySequence(group.readEntry(key, v), QKeySequence::PortableText);
+    return keySequence;
 }
 
 bool ActionsModel::keyConflictMessageBox(const QString &actionText)
@@ -688,8 +708,9 @@ ProxyActionsModel::ProxyActionsModel(QObject *parent)
     setDynamicSortFilter(true);
     setFilterCaseSensitivity(Qt::CaseInsensitive);
 
-    nameRegExp.setPatternOptions(QRegularExpression::CaseInsensitiveOption);
-    typeRegExp.setPatternOptions(QRegularExpression::CaseInsensitiveOption);
+    m_nameRegExp.setPatternOptions(QRegularExpression::CaseInsensitiveOption);
+    m_textRegExp.setPatternOptions(QRegularExpression::CaseInsensitiveOption);
+    m_typeRegExp.setPatternOptions(QRegularExpression::CaseInsensitiveOption);
 }
 
 bool ProxyActionsModel::filterAcceptsRow(int sourceRow, const QModelIndex &sourceParent) const
@@ -698,27 +719,28 @@ bool ProxyActionsModel::filterAcceptsRow(int sourceRow, const QModelIndex &sourc
     QModelIndex typeIndex = sourceModel()->index(sourceRow, 0, sourceParent);
 
     QString name = sourceModel()->data(nameIndex, ActionsModel::NameRole).toString();
+    QString text = sourceModel()->data(nameIndex, ActionsModel::TextRole).toString();
     QString type = sourceModel()->data(typeIndex, ActionsModel::TypeRole).toString();
 
-    return (name.contains(nameRegExp) && type.contains(typeRegExp));
+    return ((name.contains(m_nameRegExp) || text.contains(m_nameRegExp)) && type.contains(m_typeRegExp));
 }
 
 void ProxyActionsModel::setNameFilter(const QString &regExp)
 {
-    nameRegExp.setPattern(regExp);
+    m_nameRegExp.setPattern(regExp);
     invalidateFilter();
 }
 
 void ProxyActionsModel::setTypeFilter(const QString &regExp)
 {
-    typeRegExp.setPattern(regExp);
+    m_typeRegExp.setPattern(regExp);
     invalidateFilter();
 }
 
-bool ProxyActionsModel::saveShortcut(int row, const QVariant &shortcut)
+bool ProxyActionsModel::saveShortcut(int row, QKeySequence keySequence)
 {
     auto actionsModel = qobject_cast<ActionsModel *>(sourceModel());
-    return actionsModel->saveShortcut(mapToSource(index(row, 0)).row(), shortcut);
+    return actionsModel->saveShortcut(mapToSource(index(row, 0)).row(), keySequence);
 }
 
 #include "moc_actionsmodel.cpp"
