@@ -9,7 +9,6 @@
 #include <KConfig>
 #include <KConfigGroup>
 
-#include "global.h"
 #include "subtitlessettings.h"
 
 SubtitlesFoldersModel::SubtitlesFoldersModel(QObject *parent)
@@ -55,6 +54,8 @@ void SubtitlesFoldersModel::updateFolder(const QString &folder, int row)
 
     SubtitlesSettings::self()->setSubtitlesFolders(newList);
     SubtitlesSettings::self()->save();
+
+    Q_EMIT dataChanged(index(row, 0), index(row, 0));
 }
 
 void SubtitlesFoldersModel::deleteFolder(int row)
