@@ -33,12 +33,15 @@
 #include "worker.h"
 
 #if defined(Q_OS_UNIX)
+#include <QDBusConnection>
+
 #include "lockmanager.h"
 #include "mediaplayer2.h"
 #include "mediaplayer2player.h"
-#include <QDBusConnection>
 #endif
 
+using namespace Qt::StringLiterals;
+
 MpvItem::MpvItem(QQuickItem *parent)
     : MpvAbstractItem(parent)
     , m_audioTracksModel{std::make_unique<TracksModel>()}
@@ -46,7 +49,7 @@ MpvItem::MpvItem(QQuickItem *parent)
     , m_playlistModel{std::make_unique<PlaylistModel>()}
     , m_playlistProxyModel{std::make_unique<PlaylistProxyModel>()}
     , m_chaptersModel{std::make_unique<ChaptersModel>()}
-    , m_watchLaterPath{QString(Global::instance()->appConfigDirPath()).append(QStringLiteral("/watch-later/"))}
+    , m_watchLaterPath{QString(Global::instance()->appConfigDirPath()).append(u"/watch-later/"_s)}
     , m_saveTimePositionTimer{std::make_unique<QTimer>()}
 {
     m_playlistProxyModel->setSourceModel(m_playlistModel.get());
@@ -66,6 +69,7 @@ MpvItem::MpvItem(QQuickItem *parent)
     Q_EMIT observeProperty(MpvProperties::self()->Chapter, MPV_FORMAT_INT64);
     Q_EMIT observeProperty(MpvProperties::self()->ChapterList, MPV_FORMAT_NODE);
     Q_EMIT observeProperty(MpvProperties::self()->TracksCount, MPV_FORMAT_NODE);
+    Q_EMIT observeProperty(MpvProperties::self()->SubtitleDelay, MPV_FORMAT_DOUBLE);
 
     setupConnections();
     initProperties();
@@ -102,7 +106,7 @@ MpvItem::MpvItem(QQuickItem *parent)
         auto configGroup = m_customPropsConfig->group(_group);
         QString type = configGroup.readEntry("Type", QString());
         bool setOnStartup = configGroup.readEntry("SetOnStartup", true);
-        if (type == QStringLiteral("startup") && setOnStartup) {
+        if (type == u"startup"_s && setOnStartup) {
             userCommand(configGroup.readEntry("Command", QString()));
         }
     }
@@ -114,26 +118,25 @@ MpvItem::~MpvItem()
 
 void MpvItem::initProperties()
 {
-    //    setProperty(QStringLiteral("terminal"), InformationSettings::mpvLogging());
-    //    setProperty(QStringLiteral("msg-level"), QStringLiteral("all=v"));
+    //    setProperty(u"terminal"_s, InformationSettings::mpvLogging());
+    //    setProperty(u"msg-level"_s, u"all=v"_s);
 
-    Q_EMIT setProperty(MpvProperties::self()->VO, QStringLiteral("libmpv"));
+    Q_EMIT setProperty(MpvProperties::self()->VO, u"libmpv"_s);
 
-    QString hwdec = PlaybackSettings::useHWDecoding() ? PlaybackSettings::hWDecoding() : QStringLiteral("no");
-    Q_EMIT setProperty(MpvProperties::self()->HardwareDecoding, hwdec);
+    Q_EMIT setProperty(MpvProperties::self()->HardwareDecoding, PlaybackSettings::hWDecoding());
     Q_EMIT setProperty(MpvProperties::self()->Volume, AudioSettings::volume());
     Q_EMIT setProperty(MpvProperties::self()->VolumeMax, 100);
 
     // set ytdl_path to yt-dlp or fallback to youtube-dl
-    Q_EMIT setProperty(MpvProperties::self()->ScriptOpts, QStringLiteral("ytdl_hook-ytdl_path=%1").arg(Application::youtubeDlExecutable()));
+    Q_EMIT setProperty(MpvProperties::self()->ScriptOpts, u"ytdl_hook-ytdl_path=%1"_s.arg(Application::youtubeDlExecutable()));
     QCommandLineParser *cmdParser = Application::instance()->parser();
     QString ytdlFormat = PlaybackSettings::ytdlFormat();
-    if (cmdParser->isSet(QStringLiteral("ytdl-format-selection"))) {
-        ytdlFormat = cmdParser->value(QStringLiteral("ytdl-format-selection"));
+    if (cmdParser->isSet(u"ytdl-format-selection"_s)) {
+        ytdlFormat = cmdParser->value(u"ytdl-format-selection"_s);
     }
     Q_EMIT setProperty(MpvProperties::self()->YtdlFormat, ytdlFormat);
 
-    Q_EMIT setProperty(MpvProperties::self()->SubtitleAuto, QStringLiteral("exact"));
+    Q_EMIT setProperty(MpvProperties::self()->SubtitleAuto, u"exact"_s);
     Q_EMIT setProperty(MpvProperties::self()->SubtitleUseMargins, SubtitlesSettings::allowOnBlackBorders());
     Q_EMIT setProperty(MpvProperties::self()->SubtitleAssForceMargins, SubtitlesSettings::allowOnBlackBorders());
     Q_EMIT setProperty(MpvProperties::self()->SubtitleFont, SubtitlesSettings::fontFamily());
@@ -145,19 +148,16 @@ void MpvItem::initProperties()
     Q_EMIT setProperty(MpvProperties::self()->SubtitleBorderSize, SubtitlesSettings::borderSize());
     Q_EMIT setProperty(MpvProperties::self()->SubtitleBold, SubtitlesSettings::isBold());
     Q_EMIT setProperty(MpvProperties::self()->SubtitleItalic, SubtitlesSettings::isItalic());
+    Q_EMIT setProperty(MpvProperties::self()->SubtitleFilePaths, SubtitlesSettings::subtitlesFolders().join(u":"_s));
+    selectSubtitleTrack();
 
     Q_EMIT setProperty(MpvProperties::self()->ScreenshotTemplate, VideoSettings::screenshotTemplate());
     Q_EMIT setProperty(MpvProperties::self()->ScreenshotFormat, VideoSettings::screenshotFormat());
 
-    Q_EMIT setProperty(MpvProperties::self()->AudioClientName, QStringLiteral("haruna"));
+    Q_EMIT setProperty(MpvProperties::self()->AudioClientName, u"haruna"_s);
     const QVariant preferredAudioTrack = AudioSettings::preferredTrack();
-    Q_EMIT setProperty(MpvProperties::self()->AudioId, preferredAudioTrack == 0 ? QStringLiteral("auto") : preferredAudioTrack);
-    Q_EMIT setProperty(MpvProperties::self()->AudioLanguage, AudioSettings::preferredLanguage().remove(QStringLiteral(" ")));
-
-    const QVariant preferredSubTrack = SubtitlesSettings::preferredTrack();
-    Q_EMIT setProperty(MpvProperties::self()->SubtitleId, preferredSubTrack == 0 ? QStringLiteral("auto") : preferredSubTrack);
-    Q_EMIT setProperty(MpvProperties::self()->SubtitleLanguage, SubtitlesSettings::preferredLanguage().remove(QStringLiteral(" ")));
-    Q_EMIT setProperty(MpvProperties::self()->SubtitleFilePaths, SubtitlesSettings::subtitlesFolders().join(QStringLiteral(":")));
+    Q_EMIT setProperty(MpvProperties::self()->AudioId, preferredAudioTrack == 0 ? u"auto"_s : preferredAudioTrack);
+    Q_EMIT setProperty(MpvProperties::self()->AudioLanguage, AudioSettings::preferredLanguage().remove(u" "_s));
 }
 
 void MpvItem::setupConnections()
@@ -182,31 +182,16 @@ void MpvItem::setupConnections()
         setFinishedLoading(false);
     });
 
-    connect(mpvController(), &MpvController::fileLoaded, this, [=]() {
+    connect(mpvController(), &MpvController::fileLoaded, this, [this]() {
         getPropertyAsync(MpvProperties::self()->ChapterList, static_cast<int>(AsyncIds::ChapterList));
         getPropertyAsync(MpvProperties::self()->VideoId, static_cast<int>(AsyncIds::VideoId));
         getPropertyAsync(MpvProperties::self()->TrackList, static_cast<int>(AsyncIds::TrackList));
 
-        if (m_playlistModel->rowCount() <= 1 && PlaylistSettings::repeat()) {
-            Q_EMIT setProperty(MpvProperties::self()->LoopFile, QStringLiteral("inf"));
-        }
-
-        Q_EMIT setProperty(MpvProperties::self()->ABLoopA, QStringLiteral("no"));
-        Q_EMIT setProperty(MpvProperties::self()->ABLoopB, QStringLiteral("no"));
-
-        // this is only run when reloading the last file in the playlist
-        // due to the playlist repeat setting being turned off
-        if (isFileReloaded()) {
-            setPause(true);
-            setPosition(0);
-            setIsFileReloaded(false);
-            setFinishedLoading(true);
-            return;
-        }
+        Q_EMIT setProperty(MpvProperties::self()->ABLoopA, u"no"_s);
+        Q_EMIT setProperty(MpvProperties::self()->ABLoopB, u"no"_s);
 
         setFinishedLoading(true);
         Q_EMIT fileLoaded();
-
     }, Qt::QueuedConnection);
 
     connect(this, &MpvItem::positionChanged, this, [this]() {
@@ -229,9 +214,9 @@ void MpvItem::setupConnections()
 
 #if HAVE_DBUS
     // register mpris dbus service
-    QString mspris2Name(QStringLiteral("org.mpris.MediaPlayer2.haruna"));
+    QString mspris2Name(u"org.mpris.MediaPlayer2.haruna"_s);
     QDBusConnection::sessionBus().registerService(mspris2Name);
-    QDBusConnection::sessionBus().registerObject(QStringLiteral("/org/mpris/MediaPlayer2"), this, QDBusConnection::ExportAdaptors);
+    QDBusConnection::sessionBus().registerObject(u"/org/mpris/MediaPlayer2"_s, this, QDBusConnection::ExportAdaptors);
     // org.mpris.MediaPlayer2 mpris2 interface
     auto mp2 = new MediaPlayer2(this);
     connect(mp2, &MediaPlayer2::raise, this, &MpvItem::raise);
@@ -256,7 +241,7 @@ void MpvItem::setupConnections()
         Q_EMIT playPrevious();
     });
     connect(mp2Player, &MediaPlayer2Player::seek, this, [=](int offset) {
-        Q_EMIT command(QStringList() << QStringLiteral("add") << QStringLiteral("time-pos") << QString::number(offset));
+        Q_EMIT command(QStringList() << u"add"_s << u"time-pos"_s << QString::number(offset));
     });
     connect(mp2Player, &MediaPlayer2Player::openUri, this, [=](const QString &uri) {
         Q_EMIT openUri(uri);
@@ -266,10 +251,10 @@ void MpvItem::setupConnections()
 #if defined(Q_OS_UNIX)
     connect(this, &MpvItem::pauseChanged, this, [=]() {
         static LockManager lockManager;
-        if (pause()) {
-            lockManager.setInhibitionOff();
-        } else {
+        if (!pause() && !m_currentUrl.isEmpty()) {
             lockManager.setInhibitionOn();
+        } else {
+            lockManager.setInhibitionOff();
         }
     });
 #endif
@@ -278,32 +263,6 @@ void MpvItem::setupConnections()
     // clang-format on
 }
 
-void MpvItem::onEndFile(const QString &reason)
-{
-    if (reason == u"error"_qs) {
-        if (playlistModel()->rowCount() == 0) {
-            return;
-        }
-
-        const auto index = playlistProxyModel()->index(playlistProxyModel()->getPlayingItem(), 0);
-        const auto title = playlistModel()->data(playlistProxyModel()->mapToSource(index), PlaylistModel::TitleRole);
-
-        Q_EMIT osdMessage(i18nc("@info:tooltip", "Could not play: %1", title.toString()));
-    }
-
-    if (playlistProxyModel()->getPlayingItem() + 1 < playlistModel()->rowCount()) {
-        playlistProxyModel()->playNext();
-    } else {
-        // Last file in playlist
-        if (PlaylistSettings::repeat()) {
-            playlistProxyModel()->setPlayingItem(0);
-        } else {
-            setIsFileReloaded(true);
-            playlistProxyModel()->setPlayingItem(playlistProxyModel()->getPlayingItem());
-        }
-    }
-}
-
 void MpvItem::onReady()
 {
     setIsReady(true);
@@ -325,6 +284,37 @@ void MpvItem::onReady()
     }
 }
 
+void MpvItem::onEndFile(const QString &reason)
+{
+    int currentItem = playlistProxyModel()->getPlayingItem();
+    if (reason == u"error"_s) {
+        if (playlistModel()->rowCount() == 0) {
+            return;
+        }
+
+        const auto index = playlistProxyModel()->index(currentItem, 0);
+        const auto title = playlistModel()->data(playlistProxyModel()->mapToSource(index), PlaylistModel::TitleRole);
+
+        Q_EMIT osdMessage(i18nc("@info:tooltip", "Could not play: %1", title.toString()));
+    }
+
+    if (!playlistProxyModel()->isLastItem(currentItem)) {
+        playlistProxyModel()->playNext();
+        return;
+    }
+
+    // Last file in playlist
+    if (PlaylistSettings::repeat()) {
+        // repeat is on -> open first item in the playlist
+        playlistProxyModel()->setPlayingItem(0);
+        return;
+    }
+
+    // repeat is off -> reopen the last file paused
+    setPropertyBlocking(MpvProperties::self()->Pause, true);
+    Q_EMIT command(QStringList() << u"loadfile"_s << m_currentUrl.toString());
+}
+
 void MpvItem::onPropertyChanged(const QString &property, const QVariant &value)
 {
     if (property == MpvProperties::self()->MediaTitle) {
@@ -384,6 +374,15 @@ void MpvItem::onPropertyChanged(const QString &property, const QVariant &value)
         m_secondarySubtitleId = value.toInt();
         Q_EMIT secondarySubtitleIdChanged();
 
+    } else if (property == MpvProperties::self()->SubtitleDelay) {
+        auto delay = QString::number(value.toDouble(), 'f', 2).toDouble();
+        auto delayString = QLocale().toString(delay, 'f', 2);
+        if (delay > 0) {
+            Q_EMIT osdMessage(i18nc("@info:tooltip", "Subtitle timing: %1 seconds", delayString.prepend(u"+"_s)));
+        } else {
+            Q_EMIT osdMessage(i18nc("@info:tooltip", "Subtitle timing: %1 seconds", delayString));
+        }
+
     } else if (property == MpvProperties::self()->Width) {
         m_videoWidth = value.toInt();
         Q_EMIT videoWidthChanged();
@@ -391,10 +390,6 @@ void MpvItem::onPropertyChanged(const QString &property, const QVariant &value)
     } else if (property == MpvProperties::self()->Height) {
         m_videoHeight = value.toInt();
         Q_EMIT videoHeightChanged();
-
-    } else if (property == MpvProperties::self()->TracksCount) {
-        loadTracks(getProperty(MpvProperties::self()->TrackList).toList());
-        Q_EMIT videoHeightChanged();
     }
 }
 
@@ -414,9 +409,9 @@ void MpvItem::loadFile(const QString &file)
     setWatchLaterPosition(loadTimePosition());
     if (PlaybackSettings::seekToLastPosition()) {
         setPropertyBlocking(MpvProperties::self()->Pause, !PlaybackSettings::playOnResume() && watchLaterPosition() > 1);
-        setPropertyBlocking(u"start"_qs, QVariant(u"+"_qs + QString::number(m_watchLaterPosition)));
+        setPropertyBlocking(u"start"_s, QVariant(u"+"_s + QString::number(m_watchLaterPosition)));
     }
-    Q_EMIT command(QStringList() << QStringLiteral("loadfile") << m_currentUrl.toString());
+    Q_EMIT command(QStringList() << u"loadfile"_s << m_currentUrl.toString());
     setPropertyBlocking(MpvProperties::self()->Mute, mute);
 
     GeneralSettings::setLastPlayedFile(m_currentUrl.toString());
@@ -425,26 +420,32 @@ void MpvItem::loadFile(const QString &file)
 
 void MpvItem::loadTracks(QList<QVariant> tracks)
 {
-    m_subtitleTracks.clear();
-    m_audioTracks.clear();
+    m_subtitleTracksModel->clear();
+    m_audioTracksModel->clear();
 
-    QMap<QString, QVariant> none = {
-        {QStringLiteral("id"), QVariant(0)},
-        {QStringLiteral("title"), QVariant(i18nc("@action The \"None\" subtitle track is used to clear/unset selected track", "None"))},
+    Track noneTrack = {
+        0,
+        QString{},
+        i18nc("@action The \"None\" subtitle track is used to clear/unset selected track", "None"),
+        QString{},
     };
-    m_subtitleTracks.append(none);
+    m_subtitleTracksModel->addTrack(noneTrack);
 
-    for (const auto &track : tracks) {
-        const auto trackMap = track.toMap();
-        if (trackMap[QStringLiteral("type")] == QStringLiteral("sub")) {
-            m_subtitleTracks.append(track);
+    for (const auto &item : tracks) {
+        const auto map = item.toMap();
+        Track track = {
+            map[u"id"_s].toInt(),
+            map[u"lang"_s].toString(),
+            map[u"title"_s].toString(),
+            map[u"codec"_s].toString(),
+        };
+        if (map[u"type"_s] == u"sub"_s) {
+            m_subtitleTracksModel->addTrack(track);
         }
-        if (trackMap[QStringLiteral("type")] == QStringLiteral("audio")) {
-            m_audioTracks.append(track);
+        if (map[u"type"_s] == u"audio"_s) {
+            m_audioTracksModel->addTrack(track);
         }
     }
-    m_subtitleTracksModel->setTracks(std::move(m_subtitleTracks));
-    m_audioTracksModel->setTracks(std::move(m_audioTracks));
 
     Q_EMIT audioTracksModelChanged();
     Q_EMIT subtitleTracksModelChanged();
@@ -459,7 +460,7 @@ void MpvItem::onAsyncReply(const QVariant &data, mpv_event event)
     case AsyncIds::SavePosition: {
         auto hash = md5(currentUrl().toString());
         auto watchLaterConfig = QString(m_watchLaterPath).append(hash);
-        Q_EMIT syncConfigValue(watchLaterConfig, QString(), QStringLiteral("TimePosition"), data.toString());
+        Q_EMIT syncConfigValue(watchLaterConfig, QString(), u"TimePosition"_s, data.toString());
         break;
     }
     case AsyncIds::Screenshot: {
@@ -467,7 +468,7 @@ void MpvItem::onAsyncReply(const QVariant &data, mpv_event event)
             Q_EMIT osdMessage(i18nc("@info:tooltip osd", "Screenshot failed"));
             break;
         }
-        auto filename = data.toMap().value(QStringLiteral("filename")).toString();
+        auto filename = data.toMap().value(u"filename"_s).toString();
         if (filename.isEmpty()) {
             Q_EMIT osdMessage(i18nc("@info:tooltip osd", "Screenshot taken"));
         } else {
@@ -484,8 +485,8 @@ void MpvItem::onAsyncReply(const QVariant &data, mpv_event event)
         QList<Chapter> chaptersList;
         for (const auto &chapter : std::as_const(m_chaptersList)) {
             Chapter c;
-            c.title = chapter.toMap()[QStringLiteral("title")].toString();
-            c.startTime = chapter.toMap()[QStringLiteral("time")].toDouble();
+            c.title = chapter.toMap()[u"title"_s].toString();
+            c.startTime = chapter.toMap()[u"time"_s].toDouble();
             chaptersList.append(c);
         }
         m_chaptersModel->setChapters(chaptersList);
@@ -496,13 +497,13 @@ void MpvItem::onAsyncReply(const QVariant &data, mpv_event event)
             // there's no video track
             // either because the file is an audio file or the video track can't be decoded
             auto mimeType = Application::mimeType(currentUrl());
-            if (mimeType.startsWith(u"video/"_qs)) {
+            if (mimeType.startsWith(u"video/"_s)) {
                 auto errMsg = i18nc("Error message when video can't be decoded/played",
                                     "No video track detected, most likely the video track can't be decoded/played due to missing codecs");
                 Q_EMIT Application::instance()->error(errMsg);
                 break;
             }
-            Q_EMIT command(QStringList{QStringLiteral("video-add"), VideoSettings::defaultCover()});
+            Q_EMIT command(QStringList{u"video-add"_s, VideoSettings::defaultCover()});
         }
         break;
     }
@@ -520,13 +521,13 @@ void MpvItem::onChapterChanged()
         return;
     }
 
-    const QStringList words = chaptersToSkip.split(QStringLiteral(","));
+    const QStringList words = chaptersToSkip.split(u","_s);
     auto ch = m_chaptersList.value(chapter()).toMap();
-    auto title = ch.value(QStringLiteral("title")).toString();
+    auto title = ch.value(u"title"_s).toString();
     for (int i = 0; i < words.count(); ++i) {
         QString word = words.at(i).toLower().simplified();
         if (!ch.isEmpty() && title.contains(word, Qt::CaseInsensitive)) {
-            Q_EMIT command({QStringLiteral("add"), QStringLiteral("chapter"), QStringLiteral("1")});
+            Q_EMIT command({u"add"_s, u"chapter"_s, u"1"_s});
             if (PlaybackSettings::showOsdOnSkipChapters()) {
                 Q_EMIT osdMessage(i18nc("@info:tooltip osd", "Skipped chapter: %1", title));
             }
@@ -537,8 +538,7 @@ void MpvItem::onChapterChanged()
 
 void MpvItem::saveTimePosition()
 {
-    // saving position is disabled
-    if (PlaybackSettings::minDurationToSavePosition() == -1) {
+    if (!PlaybackSettings::restoreFilePosition()) {
         return;
     }
     // position is saved only for files longer than PlaybackSettings::minDurationToSavePosition()
@@ -551,8 +551,7 @@ void MpvItem::saveTimePosition()
 
 double MpvItem::loadTimePosition()
 {
-    // saving position is disabled
-    if (PlaybackSettings::minDurationToSavePosition() == -1) {
+    if (!PlaybackSettings::restoreFilePosition()) {
         return 0;
     }
     PlaylistItem item{m_playlistModel->m_playlist[m_playlistModel->m_playingItem]};
@@ -573,7 +572,7 @@ double MpvItem::loadTimePosition()
 
     // position for files with a duration lower than
     // PlaybackSettings::minDurationToSavePosition() is not restored
-    if (duration < PlaybackSettings::minDurationToSavePosition() * 60) {
+    if (m_currentUrl.isLocalFile() && duration < PlaybackSettings::minDurationToSavePosition() * 60) {
         return 0;
     }
 
@@ -603,6 +602,16 @@ void MpvItem::userCommand(const QString &commandString)
     Q_EMIT command(args);
 }
 
+void MpvItem::selectSubtitleTrack()
+{
+    Q_EMIT setProperty(MpvProperties::self()->SubtitleId, u"no"_s);
+    if (SubtitlesSettings::autoSelectSubtitles()) {
+        const QVariant preferredSubTrack = SubtitlesSettings::preferredTrack();
+        Q_EMIT setProperty(MpvProperties::self()->SubtitleId, preferredSubTrack == 0 ? u"auto"_s : preferredSubTrack);
+        Q_EMIT setProperty(MpvProperties::self()->SubtitleLanguage, SubtitlesSettings::preferredLanguage().remove(u" "_s));
+    }
+}
+
 QString MpvItem::md5(const QString &str)
 {
     auto md5 = QCryptographicHash::hash((str.toUtf8()), QCryptographicHash::Md5);
@@ -654,20 +663,6 @@ TracksModel *MpvItem::audioTracksModel() const
     return m_audioTracksModel.get();
 }
 
-bool MpvItem::isFileReloaded() const
-{
-    return m_isFileReloaded;
-}
-
-void MpvItem::setIsFileReloaded(bool _isFileReloaded)
-{
-    if (m_isFileReloaded == _isFileReloaded) {
-        return;
-    }
-    m_isFileReloaded = _isFileReloaded;
-    Q_EMIT isFileReloadedChanged();
-}
-
 QString MpvItem::mediaTitle()
 {
     return m_mediaTitle;
@@ -683,7 +678,7 @@ void MpvItem::setPosition(double value)
     if (qFuzzyCompare(value, position())) {
         return;
     }
-    Q_EMIT setProperty(MpvProperties::self()->Position, value);
+    Q_EMIT setPropertyAsync(MpvProperties::self()->Position, value);
 }
 
 double MpvItem::remaining()
