@@ -8,6 +8,7 @@
 #define MPVOBJECT_H
 
 #include <MpvAbstractItem>
+
 #include <memory>
 
 class ChaptersModel;
@@ -53,14 +54,6 @@ public:
     ChaptersModel *chaptersModel() const;
     void setChaptersModel(ChaptersModel *_chaptersModel);
 
-    /**
-     * when playlist repeat is turned off the last file in the playlist is reloaded
-     * this property is used to pause the player
-     */
-    Q_PROPERTY(bool isFileReloaded READ isFileReloaded WRITE setIsFileReloaded NOTIFY isFileReloadedChanged)
-    bool isFileReloaded() const;
-    void setIsFileReloaded(bool _isFileReloaded);
-
     Q_PROPERTY(QString mediaTitle READ mediaTitle NOTIFY mediaTitleChanged)
     QString mediaTitle();
 
@@ -150,6 +143,7 @@ public:
 
     Q_INVOKABLE void loadFile(const QString &file);
     Q_INVOKABLE void userCommand(const QString &commandString);
+    Q_INVOKABLE void selectSubtitleTrack();
 
 Q_SIGNALS:
     void audioTracksModelChanged();
@@ -160,7 +154,6 @@ Q_SIGNALS:
     void finishedLoadingChanged();
     void playlistTitleChanged();
     void playlistUrlChanged();
-    void isFileReloadedChanged();
     void mediaTitleChanged();
     void currentUrlChanged();
     void watchPercentageChanged();
@@ -210,8 +203,6 @@ private:
 
     std::unique_ptr<TracksModel> m_audioTracksModel;
     std::unique_ptr<TracksModel> m_subtitleTracksModel;
-    QList<QVariant> m_subtitleTracks;
-    QList<QVariant> m_audioTracks;
     QList<int> m_secondsWatched;
     double m_watchPercentage{0.0};
     std::unique_ptr<PlaylistModel> m_playlistModel;
@@ -237,7 +228,6 @@ private:
     QList<QVariant> m_chaptersList;
 
     double m_watchLaterPosition{0.0};
-    bool m_isFileReloaded{false};
     bool m_isReady{false};
     QUrl m_currentUrl;
     std::unique_ptr<ChaptersModel> m_chaptersModel;
